@@ -12,6 +12,7 @@ namespace eval sitzknochenabstand {
     variable N_ROWS 16
     variable N_COLS 28
     variable N_AVG 5; # Anzahl der Bilder, über die der Durschnitt gebildet wird
+    variable n_started 0; # Zählt, wie oft die App gestartet wurde
     variable druckbilder [list]
     variable vsums [list]
     variable n_druckbilder 0
@@ -77,10 +78,10 @@ namespace eval sitzknochenabstand {
 
         # Hinweis: Der Kode enthält - historisch bedingt - überflüssige Zustandsvariablen,
         #          tut aber, was er soll.
-        srvLog [namespace current]::handleDBLDValues Debug "v_sum = $v_sum"
         set start_analyse 0
         set show_image 0
         if {$v_sum > 0} {; # Druck vorhanden => Prüfe, ob Auswertung sinnvoll ist
+            srvLog [namespace current]::handleDBLDValues Debug "v_sum = $v_sum"
             if {!$finished} {
                 if {$n_druckbilder == 0} {
                     ::WSServer::disposeServerMessage apps/sitzknochenabstand text [::kvlist2json {wsevent restart}]
@@ -126,6 +127,9 @@ namespace eval sitzknochenabstand {
                 set show_image 1
             }; # if !$finished
         } else {; # Kein Druck => von vorn anfangen, sobald wieder Druck anliegt
+            if {$n_druckbilder > 0} {
+                srvLog [namespace current]::handleDBLDValues Debug "v_sum = $v_sum"
+            }
             set n_druckbilder 0
             set i_druckbild 0
             set finished 0
@@ -447,12 +451,18 @@ namespace eval sitzknochenabstand {
     proc start {} {; #{{{
         variable N_ROWS
         variable N_COLS
+        variable n_started
         variable appsettings
         variable jpegoptions
 
         srvLog [namespace current] Info "Starting App ..."
         # Callbacks setzten
-        ::kernel::TTYHocker::addDriverHandler [namespace current]::handleUSBDriverChange
+        ::kernel::TTYHocker::addDriverHandler [namespace current]::handleUSBDriverChange; # sorgt für Statusmeldung
+        if {$n_started > 0} {
+            incr n_started
+            srvLog [namespace current] Info "Appstart $n_started"
+            return
+        }
         ::kernel::TTYHocker::addImageHandler [namespace current]::handleDBLDValues 
         ::kernel::JPEGHocker::addImageHandler [namespace current]::jpegFinished
         # Nächste Version
@@ -486,6 +496,7 @@ namespace eval sitzknochenabstand {
             ::kernel::JPEGHocker::createJPEG \$values $N_ROWS $N_COLS {$jpegoptions}
             ::kernel::NormHocker::createNorm ska_live \$values $N_ROWS $N_COLS
         "
+        incr n_started
         srvLog [namespace current] Info "App started."
         #}}}
     }; # proc start
@@ -493,8 +504,15 @@ namespace eval sitzknochenabstand {
 
     # Anwendung anhalten
     proc stop {} {; #{{{
+        variable n_started
         variable appsettings
 
+        srvLog [namespace current] Info "Stopping App ..."
+        incr n_started -1
+        if {$n_started > 0} {
+            srvLog [namespace current] Info "App still started for $n_started client(s)."
+            return
+        }
         # Callbacks zurücknehmen
         ::kernel::TTYHocker::removeImageHandler [namespace current]::handleDBLDValues 
         ::kernel::TTYHocker::removeDriverHandler [namespace current]::handleUSBDriverChange
