@@ -98,6 +98,7 @@ namespace eval Recorder {
         variable n_records 0; # Anzahl Daten sätze
         variable offs_ts 0; # Offset des Wertes vom Timestamp im Datensatz
         variable duration 0; # Dauer der Aufzeichnung in ms (Timestamp des letzten Datensatzes)
+        variable ts_rec1 0; # Timestamp des ersten Datensatzes
         # Beim Abspielen aktualisiert
         variable loop 0;    # Aufzeichnung in einer Schleife abspielen
         variable pause 0;   # Abspielen pausiert
@@ -140,7 +141,7 @@ namespace eval Recorder {
         }
         set m [expr "$s / 60"]
         set s [expr "$s % 60"]
-        set h [expr "$s / 60"]
+        set h [expr "$m / 60"]
         set m [expr "$m % 60"]
         if {!$hours && $h == 0} {
             return [format %02d:%02d $m $s]
@@ -426,17 +427,18 @@ namespace eval Recorder {
     # Nächsten Datensatz aus Aufzeichnung lesen und Senden
     #   mit Verzögerung gemäß Timestamp veranlassen
     proc readNextRecord {} {; #{{{
-        namespace upvar recording fd_read fd_read reclen reclen offs_ts offs_ts
+        namespace upvar recording fd_read fd_read reclen reclen offs_ts offs_ts ts_rec1 ts_rec1
         namespace upvar recording record record pos_record pos_record ts_last ts_last
         namespace upvar recording ts_last_pos_change ts_last_pos_change 
         namespace upvar recording loop loop speed speed fp_start fp_start
         namespace upvar recording POSREFRESH POSREFRESH
+        namespace upvar recording blocks blocks
+        variable image_handler_procnames 
 
         # Gesamten Datensatz lesen
         set pos_record [tell $fd_read]
         set record [read $fd_read $reclen]
         if {[eof $fd_read]} {
-            
             if {$loop} {; # => von vorn
                 seek $fd_read $fp_start
                 set pos_record [tell $fd_read]
@@ -445,6 +447,21 @@ namespace eval Recorder {
                 set ts_last 0
                 sendPosChange 0 1
                 srvLog [namespace current]::readNextRecord Info "Loop restart."
+                if {$ts_rec1 > 1000} {; # Leerbild einschieben.
+                    srvLog [namespace current]::readNextRecord Debug "ts_rec1: $ts_rec1 => insert empty image"
+                    # (Aber nur dann, weil es sonst eher stören könnte!)
+                    foreach block $blocks {; # Blöcke durchgehen
+                        # Leeren Block an die Handler verteilen
+                        foreach image_handler_procname $image_handler_procnames {
+                            set id [dict get $block id]
+                            set n_rows [dict get $block n_rows]
+                            set n_cols [dict get $block n_cols]
+                            set values [lrepeat [expr $n_rows * $n_cols] 0]
+                            $image_handler_procname $id $values $n_rows $n_cols
+                            srvLog [namespace current]::readNextRecord Debug "Empty image sent: id = $id"
+                        }
+                    }
+                }
             } else {
                 sendPosChange $ts_last 1
                 stop
@@ -466,13 +483,13 @@ namespace eval Recorder {
                 }
             }
         }
-        set ts_last $ts
-        set recording::send_after_id [after $delay [namespace current]::sendNextRecord]
         if {$delay > $POSREFRESH} {; # Die Fortschrittsanzeige schläft (vorübergehend) ein.
             # => Mit einer after-Prozedur überbrücken
             set ts_last_pos_change $ts_last
             after $POSREFRESH "[namespace current]::checkPosChangeDelay $delay"
         }
+        set ts_last $ts
+        set recording::send_after_id [after $delay [namespace current]::sendNextRecord]
         #}}}
     }; # proc readNextRecord 
 
@@ -746,8 +763,9 @@ namespace eval Recorder {
             set recording::offs_ts $offs_ts
             set recording::fp_last $fp_last
             set recording::blocks [dict get $recording_info blocks]
+            set recording::ts_rec1 $ts_rec1
             # Statusvariablen zurücksetzen
-            set recording::ts_last $ts_rec1;
+            set recording::ts_last $ts_rec1
             # Steuervariablen zurücksetzen
             set recording::loop 0
             set recording::pause 1; # sendNextRecord soll nur das 1. Bild holen
@@ -832,6 +850,7 @@ namespace eval Recorder {
     # @param appname    Name der App oder ""
     # @param name       Name der Aufzeichnung
     # @return   ""
+    # Hinweis: Auch wenn es so scheint: appname ist nicht optional.
     proc delete {{appname {}} name} {; #{{{
         set dir "/var/local/recordings"
         if {"$appname" != ""} {
@@ -855,7 +874,7 @@ namespace eval Recorder {
     # wird es für 1 Bild gestart und danach in pause versetzt.
     # Wenn Zeitangabe nach dem Ende ist, wird stillschweigend auf dieses zurückgesetzt.
     # @param position   Position in % oder im Format [[h]h:][m]m:ss falls !$exact
-    # @param exact      position ist ein Timestamp
+    # @param exact      position ist ein Timestamp in ms
     # @return   Fehlermeldung oder ""
     proc moveto {position {exact 0}} {; #{{{
         namespace upvar recording name name appname appname
@@ -1002,6 +1021,7 @@ namespace eval Recorder {
         seek $fd_read $fp_start
         srvLog [namespace current]::play Info "File position set to 0x[format %x $fp_start]."
         set recording::loop $loop
+        set ts_last 0
         sendPosChange 0 1; # $ts_last
         # Wenn ts des 1. Records groß ist, ist es besser ein Leerbild einzuschieben,
         # ansonsten stört es nicht.
@@ -1090,7 +1110,8 @@ namespace eval Recorder {
 
     # Recorder deaktivieren
     # @param send_unload    leere Druckbilder senden (1 je Block) 
-    #                       und Position auf 0 zurücksetzen
+    #                       und Position auf 0 zurücksetzen,
+    #                       wenn gerade etwas abgespielt wurde
     # @return ""
     proc unload {{send_unload 0}} {; #{{{
         namespace upvar recording fd_read fd_read blocks blocks
@@ -1235,7 +1256,7 @@ namespace eval Recorder {
     # @param name_markers   Variablenname unter dem die Markierungen abgelegt werden:
     #                       dict mit den Positionen in % als Schlüssel
     #                           Werte sind dicts mit den Schlüsseln
-    #                               time (Position im Format hh:mm:ss) und
+    #                               ascts (Position im Format hh:mm:ss) und
     #                               timestamps (Liste der Timestamps der Notizen)
     # @return   Fehlermeldung oder ""
     proc getNoteMarks {name_markers} {; #{{{
