@@ -1,11 +1,11 @@
-const host = `http://${localStorage.getItem('smartcube')}`||"";
-const ws = `ws://${localStorage.getItem('smartcube')}`||"";
+const host = `http://${getFromLocalStorage('smartcube')}`||"";
+const ws = `ws://${getFromLocalStorage('smartcube')}`||"";
 
 const setting = new Object();
 setting.text_color = '#ffffff';
 
 const cw = document.getElementsByClassName("ska")[0].offsetWidth;
-localStorage.setItem('sk','');
+saveToLocalStorage('sk','');
 
 const httpsend = new XMLHttpRequest();
 
@@ -15,13 +15,36 @@ const apps= "sitzknochenabstand";
 const Matte = document.getElementById('Matte')
 const SmartCube = document.getElementById('SmartCube')
 
+const TitleTpfs = getFromLocalStorage('tpfs');
+
+if(TitleTpfs!='sattel'){
+  let title = document.getElementsByClassName('uk-card-title')[0];
+  title.setAttribute('key',`tpfs_head_${TitleTpfs}`);
+  translatejs();
+}
+
 
 //const baseURL ="https://www.dasberatungsportal.de/"
 const baseURL ="https://www.the-perfect-fit-system.com/"
 
+if(getFromLocalStorage('client_mail')){
+  let inp = document.getElementById('TPFSMail');
+  inp.value = getFromLocalStorage('client_mail');
+  let c = document.getElementById('BackToClient');
+  c.classList.remove('hidden');
+  let cc = document.getElementById('btn_BackToClient');
+  cc.setAttribute('onclick',`LinkTo('client.tcls')`)
+  cc.innerHTML =`${getFromLocalStorage('client_name')}`
+  var interv = setInterval( () => {
+    loadTPFS();
+    clearInterval(interv);
+  }, 1500);
+}
+
 
 var Stationsinfo = new Object();
 var Fragen = new Object();
+var user_data = new Object();
 
 let userdata = new Object();
 let isrequired = new Object();
@@ -34,12 +57,12 @@ var myChartX = echarts.init(dom, 'dark', {
   useDirtyRect: false
 });
 
-document.getElementById('product_count').value = localStorage.getItem('product_count') || 3
+document.getElementById('product_count').value = getFromLocalStorage('product_count') || 3
 //var sessionID;
-//if(localStorage.getItem('session').split(" ")[0]=='restart'){
-//  sessionID = localStorage.getItem('session').split(" ")[1]
+//if(getFromLocalStorage('session').split(" ")[0]=='restart'){
+//  sessionID = getFromLocalStorage('session').split(" ")[1]
 //} else{
-//  sessionID = localStorage.getItem('new_session')
+//  sessionID = getFromLocalStorage('new_session')
 //}
 
 const canvas_ska = new fabric.Canvas("ska_img");
@@ -53,6 +76,9 @@ var vsum = 0;
 translatejs();
 //_name();
 
+/**
+ * The function show3d toggles the 'hidden' class on the element with the id 'chart-container'.
+ */
 function show3d() {
     document.getElementById('chart-container').classList.toggle('hidden')
 }
@@ -134,7 +160,7 @@ sitzknochen.onmessage = (e) => {
             //SendSkImg();
         //  changeEventHandler(document.getElementById('sitzknochenabstand').value)
             progress(1)
-          localStorage.setItem('sk',`${cm}`)
+          saveToLocalStorage('sk',`${cm}`)
           vsum++
           clearInterval(inter);
         }, 1000);
@@ -371,7 +397,7 @@ ws_ska.onmessage = (e) =>{
             //SendSkImg();
         //  changeEventHandler(document.getElementById('sitzknochenabstand').value)
             progress(1)
-          localStorage.setItem('sk',`${cm}`)
+          saveToLocalStorage('sk',`${cm}`)
           vsum++
           clearInterval(inter);
         }, 1000);
@@ -483,7 +509,7 @@ function OpenMod(params) {
  * It gets the name from local storage and puts it in the right places
  */
 function _name() {
-  let name = localStorage.getItem('client_name').split(' ')
+  let name = getFromLocalStorage('client_name').split(' ')
   //document.getElementById('auswertung_h3').innerHTML += ' '+name[1]+" "+name[0]
   document.getElementById('name_vorname').innerHTML = name[0]+', '+name[1] 
 }
@@ -513,7 +539,10 @@ function store(val,key,a) {
 var user = document.getElementById('stnr').value;
 sessionStorage.setItem('user',user)
 
-AXIOS_Login();
+//AXIOS_Login();
+
+AXIOS_Ping();
+AXIOS_Load_Fragen();
 
 /**
  * The function AXIOS_Login sends a GET request to a login endpoint with user credentials and saves the
@@ -536,7 +565,7 @@ function AXIOS_Login() {
             }
             AXIOS_Ping();
             AXIOS_Load_Fragen();
-            AXIOS_logout();
+            //AXIOS_logout();
         })
         .catch(err => {
             OpenModDialog({type:'error',title:["error"],msg:`${err}`,master_btn:['button_ok']})
@@ -548,11 +577,12 @@ function AXIOS_Login() {
  * accordingly, including error handling.
  */
 function AXIOS_Ping() {
-    axios.get(`${ baseURL }vmkservice/ping`, {
+    axios.get(`/vlbservice/ping`, {
             method: 'GET',
             withCredentials: true
         })
         .then(response => {
+          console.log('response',response);
             if (response.data === '12 forbidden') {
                 //TODO ERROR HANDLING
                 OpenModDialog({type:'error',title:["error"],msg:`${response.data}`,master_btn:['button_ok']})
@@ -560,6 +590,7 @@ function AXIOS_Ping() {
                 console.log('error');
                 return;
             }
+            console.log('ping', response.data);
             Stationsinfo = response.data;
             time_to_use(Stationsinfo.optionen['sattel.beratung'])
             translatejs();
@@ -589,9 +620,17 @@ function AXIOS_logout() {
  * in a specific language and product type, and then processes the response data.
  */
 function AXIOS_Load_Fragen() {
+    if(getFromLocalStorage('tpfs')!='sattel'){
+      let im = document.getElementById('glow')
+      let inp= document.getElementById('val_ska')
+      let conSmart = document.getElementById('conn_smartcube')
+      conSmart.classList.add('hidden')
+      inp.classList.add('hidden')
+      im.classList.add('hidden')
+    }
     const lang = 'deu'
-    const temp = '&produktart=sattel'
-    axios.get(`${ baseURL }vmkservice/start?lang=${ lang }${ temp }`, {
+    const temp = '&produktart='+getFromLocalStorage('tpfs') //sattel, ergodreieck
+    axios.get(`/vlbservice/start?lang=${ lang }${ temp }`, {
             method: 'GET',
             withCredentials: true
         })
@@ -646,14 +685,24 @@ function AXIOS_AutoLogin() {
  * The function AXIOS_Load_Produckte makes a GET request to a specific URL with some parameters,
  * retrieves the response data, stores it in sessionStorage, and then redirects to another page.
  */
-var prod_anzahl = localStorage.getItem('product_count') || 3
+var prod_anzahl = getFromLocalStorage('tpfs') === "ergodreieck" ? 1 : getFromLocalStorage('product_count') || 3
 
+/**
+ * The function `AXIOS_Load_Produckte` sends a GET request using Axios to load product data based on
+ * various parameters and user input.
+ */
 function AXIOS_Load_Produckte() {
+    let inp = document.getElementById('TPFSMail')
     let options = {};
     let params = {};
+    if(!inp.value ==""){
+      params['#email'] = inp.value
+    }
     params.lang = 'deu';
-    params['#artcode'] = 'sattel';
-    params['#max_produkte'] = prod_anzahl;
+    params['#artcode'] = getFromLocalStorage('tpfs'); //sattel,ergodreieck
+    params['#max_produkte'] = prod_anzahl; // prod_anzahl
+    if(document.getElementById('sitzknochenabstand'))
+    params['sitzknochenabstand'] = document.getElementById('sitzknochenabstand').value
     //console.log(userdata);
     for (const key in userdata) {
         params[key] = userdata[key.replaceAll(' ','_')];
@@ -663,16 +712,20 @@ function AXIOS_Load_Produckte() {
     options.method = 'GET';
     options.withCredentials = 'true';
 
-    axios.get(`${ baseURL }vmkservice/bewerten`, options)
+    console.log('load prod:', options);
+    axios.get(`/vlbservice/bewerten`, options)
         .then(response => {
             if (response.data === '12 forbidden') {
                 return;
             }
             produkte = response.data;
+            console.log(produkte);
             sessionStorage.setItem('produkte',JSON.stringify(produkte))
-            //createModalProducts(produkte);
-            AXIOS_logout();
-            LinkTo('products.tcls')
+            console.log(getFromLocalStorage('tpfs'));
+            //if(getFromLocalStorage('tpfs')==='sattel'){
+              LinkTo('products.tcls')
+            //}
+            //AXIOS_logout();
         })
         .catch(err => {
             console.error(err);
@@ -690,11 +743,17 @@ function AXIOS_Load_Produckte() {
 function time_to_use(params) {
     let date = new Date(params)
     let today = new Date();
-    let days = `${Math.floor((date - today) / (1000*60*60*24))} ${aLangKeys[lang]['tpfs_days']}`
+    let days = `${Math.floor((date - today) / (1000*60*60*24))} ${aLangKeys[lang]['tpfs_days']||""}`
     //document.getElementById('time_beratung').innerHTML = `${aLangKeys[lang]['tpfs_use']} ${days}`
     if(Math.floor((date - today) / (1000*60*60*24)) < 182){
-        OpenModDialog({type:'warn',title:["tpfs_use"],msg:`${days}`,master_btn:['button_ok']})
+        if(Math.floor((date - today) / (1000*60*60*24)) < 0){
+          
+          OpenModDialog({type:'warn',title:["tpfs_use_end"],msg:`${days}`,master_btn:['button_ok','LinkTo("dashboard.tcls")']});
+        } else {
+          OpenModDialog({type:'warn',title:["tpfs_use"],msg:`${days}`,master_btn:['button_ok']});
+        }
     }
+    
 }
 
 /**
@@ -722,14 +781,19 @@ function create_block(jsn) {
         content = newElement({element:"div",cls:['uk-card-body']},block)
 
     }
+    var koerpermaße = ['ua','oa','ok','rhh','os','usf','skv']
     for (const key in jsn.fragen) {
         const element = jsn.fragen[key];
-        //console.log(element);
+        //console.log(element.code);
         let bl  = newElement({element:"div",cls:['block']},content)
-        let h   = newElement({element:"div",cls:["block_head"],attr:[['key',`tpfs_${element.code}`]]},bl).innerHTML = `<!--${element.code}-->`
+        if(koerpermaße.includes(element.code)){
+          let img = newElement({element:'img',attr:[['style','width:25em'],['src',`/production/images/svg/koerperdaten-${element.code}.png`]]},bl)
+        } else {
+          let h   = newElement({element:"div",cls:["block_head"],attr:[['key',`tpfs_${element.code}`]]},bl).innerHTML = `<!--${element.code}-->`
+        }
         let con = newElement({element:"div",cls:["block_content"]},bl)
         if(element.vorgaben == null){
-            let inp = newElement({element:"input",cls:["uk-input"],id:`${element.code}`,attr:[['onchange','changeEventHandler(event)'],['name',element.code],['required','true'],['data-progress',"1"]]},con)
+            let inp = newElement({element:"input",cls:["uk-input"],id:`${element.code}`,attr:[['oninput','changeEventHandler(event)'],['name',element.code],['required','true'],['data-progress',"1"]]},con)
         } else {
             genSelect(element.vorgaben,con,element.code,element.pflicht)
         }
@@ -765,8 +829,13 @@ function genSelect(jsn,to,name,pflicht) {
                 isrequired[name] = true
                 progressMax(Object.keys(isrequired).length+1)
                 if(e.code != null){
+                    //console.log(name);
+                    
+                    //if(name === 'fahrposition'&& getFromLocalStorage('tpfs')!='sattel'){
+                    //  name = 'sitzposition'
+                    //}
                     newElement({element:'input',id:`${name}_${e.code}`,cls:['question_input'],attr:[['type','radio'],['name',`${name}`],['value',`${e.code}`],['required','true'],['data-progress','1'],['onclick','changeEventHandler(event)']]},card)
-                    newElement({element:'label',cls:['question_label'],attr:[['key-title',`title_${name}${e.code}`],['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code}.png)`]]},card)
+                    newElement({element:'label',cls:['question_label'],attr:[['key-title',`title_${name}${e.code}`],['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code.replace(' ','_')}.png)`]]},card)
                     //newElement({element:"input",attr:[["style",`background: url(/production/images/svg/${name}_${e.code}.png)`],['data-value',`${e.code}`],['data-name',`${name}`],['type','radio']]},head)
                 }
             } else {
@@ -988,10 +1057,52 @@ function sendMatte(parameters) {
 }
 
 function setProductCount(param) {
-  localStorage.setItem('product_count',param)
+  saveToLocalStorage('product_count',param)
   location.reload(true)
 }
 
+function loadTPFS() {
+  let inp = document.getElementById('TPFSMail')
+
+  if(!inp.value ==""){
+    ///vlbservice/antworten?email=
+
+    axios.get(`/vlbservice/antworten?email=${inp.value}`, {
+      method: 'GET',
+      withCredentials: true
+  })
+  .then(response => {
+      if (response.data === '12 forbidden') {
+          //TODO ERROR HANDLING
+          OpenModDialog({type:'error',title:["error"],msg:`${response.data}`,master_btn:['button_ok']})
+          return;
+      }
+      user_data = response.data
+
+      for (const key in user_data) {
+          const element = user_data[key];
+          //TODO Create Block
+          console.log(`userData: ${key} -> `,element);
+          if(key === 'sitzknochenabstand'||key === 'oa'||key === 'ok'||key === 'os'||key === 'ua'||key === 'rhh'||key === 'skv'||key === 'usf'){
+            if(document.getElementById(key)){
+            document.getElementById(key).value = element
+            userdata[key] = element
+            document.getElementById('val').value = `${element} cm`
+          }
+          } else {
+            if(document.getElementById(`${key}_${element}`))
+            document.getElementById(`${key}_${element}`).click()
+          }
+      }
+  })
+  .catch(err => {
+      //TODO ERROR HANDLING
+      OpenModDialog({type:'error',title:["error"],msg:`${err}`,master_btn:['button_ok']})
+  });
+
+  }
+}
+
 //config min_rawvalue <value>
 //Set lowest accepted raw value from pressure sensor mat. Values lower than that value will be regarded to be noise.
 //(This method is from the early days of Velometriks to adapt different sensor charges. It might be replaced in the near future.)
